@@ -68,7 +68,7 @@ as.POSIXct.dates <- function(x, ...)
 {
   # need to implement our own method to correctly handle TZ
   #as.POSIXct(as.character(as.POSIXlt(x,tz="GMT")))
-  structure(as.POSIXct(as.POSIXlt(x, tz="GMT"), tz=""),class=c("POSIXt","POSIXct"))
+  structure(as.POSIXct(as.POSIXlt(x, tz="GMT"), tz="GMT"),class=c("POSIXt","POSIXct"))
 }
 as.chron.POSIXct <- function(x, ...)
 {
